@@ -20,6 +20,7 @@ from botocore.client import BaseClient, ClientMeta
 
 from .literals import (
     AlarmTypeType,
+    AnomalyDetectorTypeType,
     ComparisonOperatorType,
     HistoryItemTypeType,
     MetricStreamOutputFormatType,
@@ -60,9 +61,11 @@ from .type_defs import (
     ListTagsForResourceOutputTypeDef,
     MetricDataQueryTypeDef,
     MetricDatumTypeDef,
+    MetricMathAnomalyDetectorTypeDef,
     MetricStreamFilterTypeDef,
     PutDashboardOutputTypeDef,
     PutMetricStreamOutputTypeDef,
+    SingleMetricAnomalyDetectorTypeDef,
     TagTypeDef,
 )
 from .waiter import AlarmExistsWaiter, CompositeAlarmExistsWaiter
@@ -103,7 +106,7 @@ class Exceptions:
 
 class CloudWatchClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html)
     """
 
@@ -119,7 +122,7 @@ class CloudWatchClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#can_paginate)
         """
 
@@ -127,22 +130,24 @@ class CloudWatchClient(BaseClient):
         """
         Deletes the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.delete_alarms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.delete_alarms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_alarms)
         """
 
     def delete_anomaly_detector(
         self,
         *,
-        Namespace: str,
-        MetricName: str,
-        Stat: str,
-        Dimensions: Sequence["DimensionTypeDef"] = ...
+        Namespace: str = ...,
+        MetricName: str = ...,
+        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Stat: str = ...,
+        SingleMetricAnomalyDetector: "SingleMetricAnomalyDetectorTypeDef" = ...,
+        MetricMathAnomalyDetector: "MetricMathAnomalyDetectorTypeDef" = ...
     ) -> Dict[str, Any]:
         """
         Deletes the specified anomaly detection model from your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.delete_anomaly_detector)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.delete_anomaly_detector)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_anomaly_detector)
         """
 
@@ -150,7 +155,7 @@ class CloudWatchClient(BaseClient):
         """
         Deletes all dashboards that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.delete_dashboards)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.delete_dashboards)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_dashboards)
         """
 
@@ -158,7 +163,7 @@ class CloudWatchClient(BaseClient):
         """
         Permanently deletes the specified Contributor Insights rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.delete_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.delete_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_insight_rules)
         """
 
@@ -166,7 +171,7 @@ class CloudWatchClient(BaseClient):
         """
         Permanently deletes the metric stream that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.delete_metric_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.delete_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_metric_stream)
         """
 
@@ -185,7 +190,7 @@ class CloudWatchClient(BaseClient):
         """
         Retrieves the history for the specified alarm.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarm_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarm_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarm_history)
         """
 
@@ -205,7 +210,7 @@ class CloudWatchClient(BaseClient):
         """
         Retrieves the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarms)
         """
 
@@ -223,7 +228,7 @@ class CloudWatchClient(BaseClient):
         """
         Retrieves the alarms for the specified metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms_for_metric)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms_for_metric)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarms_for_metric)
         """
 
@@ -234,12 +239,13 @@ class CloudWatchClient(BaseClient):
         MaxResults: int = ...,
         Namespace: str = ...,
         MetricName: str = ...,
-        Dimensions: Sequence["DimensionTypeDef"] = ...
+        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        AnomalyDetectorTypes: Sequence[AnomalyDetectorTypeType] = ...
     ) -> DescribeAnomalyDetectorsOutputTypeDef:
         """
         Lists the anomaly detection models that you have created in your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.describe_anomaly_detectors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.describe_anomaly_detectors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_anomaly_detectors)
         """
 
@@ -249,7 +255,7 @@ class CloudWatchClient(BaseClient):
         """
         Returns a list of all the Contributor Insights rules in your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.describe_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.describe_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_insight_rules)
         """
 
@@ -257,7 +263,7 @@ class CloudWatchClient(BaseClient):
         """
         Disables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.disable_alarm_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.disable_alarm_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#disable_alarm_actions)
         """
 
@@ -267,7 +273,7 @@ class CloudWatchClient(BaseClient):
         """
         Disables the specified Contributor Insights rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.disable_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.disable_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#disable_insight_rules)
         """
 
@@ -275,7 +281,7 @@ class CloudWatchClient(BaseClient):
         """
         Enables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.enable_alarm_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.enable_alarm_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#enable_alarm_actions)
         """
 
@@ -283,7 +289,7 @@ class CloudWatchClient(BaseClient):
         """
         Enables the specified Contributor Insights rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.enable_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.enable_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#enable_insight_rules)
         """
 
@@ -297,7 +303,7 @@ class CloudWatchClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#generate_presigned_url)
         """
 
@@ -305,7 +311,7 @@ class CloudWatchClient(BaseClient):
         """
         Displays the details of the dashboard that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.get_dashboard)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.get_dashboard)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_dashboard)
         """
 
@@ -324,7 +330,7 @@ class CloudWatchClient(BaseClient):
         This operation returns the time series data collected by a Contributor Insights
         rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.get_insight_rule_report)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.get_insight_rule_report)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_insight_rule_report)
         """
 
@@ -343,7 +349,7 @@ class CloudWatchClient(BaseClient):
         You can use the `GetMetricData` API to retrieve as many as 500 different metrics
         in a single request, with a total of as many as 100,800 data points.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_data)
         """
 
@@ -363,7 +369,7 @@ class CloudWatchClient(BaseClient):
         """
         Gets statistics for the specified metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_statistics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_statistics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_statistics)
         """
 
@@ -371,7 +377,7 @@ class CloudWatchClient(BaseClient):
         """
         Returns information about the metric stream that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_stream)
         """
 
@@ -382,7 +388,7 @@ class CloudWatchClient(BaseClient):
         You can use the `GetMetricWidgetImage` API to retrieve a snapshot graph of one
         or more Amazon CloudWatch metrics as a bitmap image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_widget_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_widget_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_widget_image)
         """
 
@@ -392,7 +398,7 @@ class CloudWatchClient(BaseClient):
         """
         Returns a list of the dashboards for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.list_dashboards)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.list_dashboards)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_dashboards)
         """
 
@@ -402,7 +408,7 @@ class CloudWatchClient(BaseClient):
         """
         Returns a list of metric streams in this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.list_metric_streams)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.list_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_metric_streams)
         """
 
@@ -418,7 +424,7 @@ class CloudWatchClient(BaseClient):
         """
         List the specified metrics.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.list_metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.list_metrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_metrics)
         """
 
@@ -426,23 +432,25 @@ class CloudWatchClient(BaseClient):
         """
         Displays the tags associated with a CloudWatch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_tags_for_resource)
         """
 
     def put_anomaly_detector(
         self,
         *,
-        Namespace: str,
-        MetricName: str,
-        Stat: str,
+        Namespace: str = ...,
+        MetricName: str = ...,
         Dimensions: Sequence["DimensionTypeDef"] = ...,
-        Configuration: "AnomalyDetectorConfigurationTypeDef" = ...
+        Stat: str = ...,
+        Configuration: "AnomalyDetectorConfigurationTypeDef" = ...,
+        SingleMetricAnomalyDetector: "SingleMetricAnomalyDetectorTypeDef" = ...,
+        MetricMathAnomalyDetector: "MetricMathAnomalyDetectorTypeDef" = ...
     ) -> Dict[str, Any]:
         """
         Creates an anomaly detection model for a CloudWatch metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.put_anomaly_detector)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.put_anomaly_detector)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_anomaly_detector)
         """
 
@@ -461,7 +469,7 @@ class CloudWatchClient(BaseClient):
         """
         Creates or updates a *composite alarm*.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.put_composite_alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.put_composite_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_composite_alarm)
         """
 
@@ -470,7 +478,7 @@ class CloudWatchClient(BaseClient):
         Creates a dashboard if it does not already exist, or updates an existing
         dashboard.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.put_dashboard)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.put_dashboard)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_dashboard)
         """
 
@@ -485,7 +493,7 @@ class CloudWatchClient(BaseClient):
         """
         Creates a Contributor Insights rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.put_insight_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.put_insight_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_insight_rule)
         """
 
@@ -519,7 +527,7 @@ class CloudWatchClient(BaseClient):
         Creates or updates an alarm and associates it with the specified metric, metric
         math expression, or anomaly detection model.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_alarm)
         """
 
@@ -529,7 +537,7 @@ class CloudWatchClient(BaseClient):
         """
         Publishes metric data points to Amazon CloudWatch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_data)
         """
 
@@ -547,7 +555,7 @@ class CloudWatchClient(BaseClient):
         """
         Creates or updates a metric stream.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_stream)
         """
 
@@ -562,7 +570,7 @@ class CloudWatchClient(BaseClient):
         """
         Temporarily sets the state of an alarm for testing purposes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.set_alarm_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.set_alarm_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#set_alarm_state)
         """
 
@@ -570,7 +578,7 @@ class CloudWatchClient(BaseClient):
         """
         Starts the streaming of metrics for one or more of your metric streams.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.start_metric_streams)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.start_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#start_metric_streams)
         """
 
@@ -578,7 +586,7 @@ class CloudWatchClient(BaseClient):
         """
         Stops the streaming of metrics for one or more of your metric streams.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.stop_metric_streams)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.stop_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#stop_metric_streams)
         """
 
@@ -586,7 +594,7 @@ class CloudWatchClient(BaseClient):
         """
         Assigns one or more tags (key-value pairs) to the specified CloudWatch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#tag_resource)
         """
 
@@ -594,7 +602,7 @@ class CloudWatchClient(BaseClient):
         """
         Removes one or more tags from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#untag_resource)
         """
 
@@ -603,42 +611,42 @@ class CloudWatchClient(BaseClient):
         self, operation_name: Literal["describe_alarm_history"]
     ) -> DescribeAlarmHistoryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmhistorypaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_alarms"]) -> DescribeAlarmsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_metric_data"]) -> GetMetricDataPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#getmetricdatapaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_dashboards"]) -> ListDashboardsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listdashboardspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_metrics"]) -> ListMetricsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listmetricspaginator)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["alarm_exists"]) -> AlarmExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexistswaiter)
         """
 
@@ -647,6 +655,6 @@ class CloudWatchClient(BaseClient):
         self, waiter_name: Literal["composite_alarm_exists"]
     ) -> CompositeAlarmExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexistswaiter)
         """
