@@ -23,6 +23,7 @@ __all__ = (
     "AlarmExistsWaiterName",
     "AlarmTypeType",
     "AnomalyDetectorStateValueType",
+    "AnomalyDetectorTypeType",
     "ComparisonOperatorType",
     "CompositeAlarmExistsWaiterName",
     "DescribeAlarmHistoryPaginatorName",
@@ -47,6 +48,7 @@ __all__ = (
 AlarmExistsWaiterName = Literal["alarm_exists"]
 AlarmTypeType = Literal["CompositeAlarm", "MetricAlarm"]
 AnomalyDetectorStateValueType = Literal["PENDING_TRAINING", "TRAINED", "TRAINED_INSUFFICIENT_DATA"]
+AnomalyDetectorTypeType = Literal["METRIC_MATH", "SINGLE_METRIC"]
 ComparisonOperatorType = Literal[
     "GreaterThanOrEqualToThreshold",
     "GreaterThanThreshold",
@@ -111,6 +113,7 @@ ServiceName = Literal[
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -179,6 +182,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -285,6 +289,7 @@ ServiceName = Literal[
     "mgh",
     "mgn",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -318,6 +323,7 @@ ServiceName = Literal[
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
